@@ -1,4 +1,5 @@
-from pollination.ladybug_comfort.map import PmvMap, AdaptiveMap, UtciMap
+from pollination.ladybug_comfort.map import PmvMap, AdaptiveMap, UtciMap, \
+    MapResultInfo, Tcp
 from queenbee.plugin.function import Function
 
 
@@ -18,3 +19,15 @@ def test_utci_map():
     function = UtciMap().queenbee
     assert function.name == 'utci-map'
     assert isinstance(function, Function)
+
+
+def test_map_result_info():
+    function = MapResultInfo().queenbee
+    assert function.name == 'map-result-info'
+    assert isinstance(function, Function)
+
+
+def test_tcp():
+    function = Tcp().queenbee
+    assert function.name == 'tcp'
+    assert isinstance(function, Function)
